#[non_exhaustive]pub enum InterfaceError {
DefaultInterfaceUnavailable {
message: String,
},
DefaultGatewayUnavailable {
message: String,
},
}Expand description
Errors returned when discovering system network interfaces or gateways.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The operating system did not provide a default network interface.
The operating system did not provide a default gateway.