Module ip

Module ip 

IP address utilities.

Functions

is_global_ip
Returns true if the address appears to be globally routable.
is_global_ipv4
Returns true if the address appears to be globally reachable as specified by the [IANA IPv4 Special-Purpose Address Registry].
is_global_ipv6
Returns true if the address appears to be globally reachable as specified by the [IANA IPv6 Special-Purpose Address Registry].
unspecified_ip_for
Returns an unspecified IP (0.0.0.0 / ::) with the same family as ip_addr.
unspecified_socket_addr_for
Returns an unspecified socket address with the same family as ip_addr.