IP address utilities.
Functions
- is_
global_ ip - Returns
trueif the address appears to be globally routable. - is_
global_ ipv4 - Returns
trueif the address appears to be globally reachable as specified by the [IANA IPv4 Special-Purpose Address Registry]. - is_
global_ ipv6 - Returns
trueif the address appears to be globally reachable as specified by the [IANA IPv6 Special-Purpose Address Registry]. - unspecified_
ip_ for - Returns an unspecified IP (
0.0.0.0/::) with the same family asip_addr. - unspecified_
socket_ addr_ for - Returns an unspecified socket address with the same family as
ip_addr.